% Getting the pictures 3-5 for the paper
clear
close all
clc

%Create the matrices with values of each required variable for all the
%groups analysed. Get them by looping over GE_compStatic_i files that encompass
%the values for different steps of the reform (steps 1 to 5)

for i=1:5
    
    str=sprintf('GE_compStatic_%d', i);
    load(str);
    
    if round == 1
        effort=effortIniVector;
        tightness=VarData(7,:);
        arrivalRate=mueBarVector;
        unemplRate = uRates;
        tax=kappa;
        wage=VarData(1,:);
        gross_wage=VarData(1,:)./(1-kappa);
        J_all=J;
        workersValue=Vw;
        value_of_unemp_at_0=V0;
        
    else
        
        effort=[effort;effortIniVector];    %append the vectors with values before the reform with values from the subsequent reform steps
        tightness=[tightness; VarData(7,:)];
        arrivalRate=[arrivalRate; mueBarVector];
        unemplRate = [unemplRate; uRates];
        tax=[tax;kappa];
        wage=[wage;VarData(1,:)];
        gross_wage=[gross_wage; VarData(1,:)./(1-kappa)];
        J_all=[J_all;J];
        workersValue=[workersValue; Vw];
        value_of_unemp_at_0=[value_of_unemp_at_0; V0];
        
    end
end

clear str

changes=0:1:4;  %get the "steps" of the reform

v = get(0,'MonitorPosition');
set(0,'DefaultAxesColorOrder',[0 0 0], 'DefaultAxesLineStyleOrder','-|--|:|-.|-*|-x')

figure(3)
set(gcf,'PaperPositionMode','auto','Position', 8.5*v);
%Plot the figure looping over the groups analysed (over k)

for k=1:6 % plot different groups
    
    subplot(2,4,1)      % effort at s=0
    plot(changes,effort(:,k)); title('effort at s=0','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]);
    hold all
    
    subplot(2,4,2);     %tightness
    plot(changes,tightness(:,k)); title('tightness','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]);
    hold all
    
    
    subplot(2,4,3)    % plot average job arrival rate
    plot(changes,arrivalRate(:,k)); title('average exit rate','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]);
    hold all
    
    subplot(2,3,5)     % plot net wage
    plot(changes, wage(:,k)); title('net wage','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]);
    hold all
    
    subplot(2,3,6)      % plot gross wage
    plot(changes, gross_wage(:,k)); title('gross wage','FontSize',16);
    set(gca,'FontSize',9)
    xlim([-1 5]);
    hold all
end

    h=legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low', 'Location','BestOutside');
    set(h,'Interpreter','none'); legend('boxoff')

subplot(2,4,4)  % plot unemployment rate
plot(changes, unemplRate); title('unemployment rates','FontSize',16)
set(gca,'FontSize',10)
axis([-1 5 -0.02 .25]);
hold all

subplot(2,3,4)  % plot tax rate
plot(changes, tax); title('taxes','FontSize',16);
set(gca,'FontSize',10)
axis([-1 5 -0.02 .15]);
hold all

saveas(gcf,'figure3neu','eps')

figure(4)
for k=1:6
    
    subplot(2,3,1)  % firm's value
    plot(changes,J_all(:,k)); title('value of the firm','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]); axis 'auto y';
    hold all
    
    subplot(2,3,2)  % worker's value
    plot(changes,workersValue(:,k)); title('value of a worker','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]); axis 'auto y';
    hold all
    
    subplot(2,3,3); %value_of_unemp_at_0
    plot(changes,value_of_unemp_at_0(:,k)); title('Value of unemplyment at s=0','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]);
    hold all
    
end

saveas(gcf,'figure4','eps')

%% sBar and bUA steps

for i=1:5
    str=sprintf('GE_compStatic_%d', i);
    load(str)
    if round == 1
        bUA=VarData(11,:);
        sbar=VarData(9,:);
    else
        bUA=[bUA;VarData(11,:)];    %append the vectors with values before the reform with values from the subsequent reform steps
        sbar=[sbar; VarData(9,:)];
    end
end

figure(6)
for k=1:6
    
    subplot(1,2,1)
    plot(changes, sbar(:,k)); title('sBar','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]); axis 'auto y';
    hold all
    
    subplot(1,2,2)
    plot(changes, bUA(:,k)); title('bUA','FontSize',16)
    set(gca,'FontSize',10)
    xlim([-1 5]);  ylim([90 200]);
    hold all
end

%    h=legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low', 'Location','BestOutside');
    h=legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low');
    set(h,'Interpreter','none'); legend('boxoff')

saveas(gcf,'sBar_bUA_steps','eps')


