% This file is to create the 3-5 graphs for the paper. For the matrix
% paperGraphsDataBasic and paperGraphsDataNormalised creation go to
% gettingGraphsData.m
    close all
    clear all

%Flag
    GraphType = 2;     %1: basic graph (not normalized), 2: mirrored (pre-reform on the right side, not normalized), else: mirrored and normalised

v = get(0,'MonitorPosition');
set(0,'DefaultAxesColorOrder',[0 0 0], 'DefaultAxesLineStyleOrder','-|--|-.|-d|--d|-.d')


if GraphType==1
    changes=0:1:5;  %get the "steps" of the reform - pre-reform state on the left side
    d=[-0.7 5.5]; %limits of the x axis
else
    changes=1:-1:-4;  %get the "steps" of the reform - pre-reform state on the right side
    d=[-4.4 1.4];      %limits of the x axis
end

if GraphType==1
    string='basic';
    load paperGraphsDataBasic
elseif GraphType==2 
    string='mirrored';
    load paperGraphsDataBasic
else
    string='normalisedMirrored';
    load paperGraphsDataNormalised
end

%% figure with effort tightness up to gross wage
    figure(3)
    set(gcf,'PaperPositionMode','auto','Position', 8.5*v);

    %Plot the figure looping over the groups analysed (over k)
    for k=1:6 % plot different groups
        
        subplot(2,4,1)      % effort at s=0
        plot(changes,effort(:,k)); title('effort (s=0)','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,4,2);     %tightness
        plot(changes,tightness(:,k)); title('tightness','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
               
        subplot(2,4,3)    % plot average job arrival rate
        plot(changes,arrivalRate(:,k)); title('average exit rate','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,4,4)  % plot unemployment rate
        plot(changes, unemplRates); title('unemployment rates','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,4,6)     % plot net wage
        plot(changes, wage(:,k)); title('net wage','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,4,7)      % plot gross wage
        plot(changes, gross_wage(:,k)); title('gross wage','FontSize',16);
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,4,8)     
        leg1=plot(changes, 0);
        ylim([1 2])
        set(gca,'FontSize',20)
        axis(leg1,'off')
        % this is a fake subplot, just used to show the legend here
        
    end
    
    h=legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low','Location','NorthWest');
    set(h,'Interpreter','none'); legend('boxoff')
    

    
    subplot(2,4,5)  % plot tax rate
    plot(changes, tax); title('labour tax','FontSize',16);
    set(gca,'FontSize',10)
    xlim(d);
    set(gca,'XTick',[-4 -3 -2 -1 0 1])
    if GraphType==1 || GraphType==2
        ylim([-0.02 0.07]);
    else
        ylim([0.7 1.05]);
    end
    hold all
    
    name=sprintf('%s%s','figure3_', string);
    saveas(gcf,name,'eps')
    
    
%% figure on value functions and welfare   
    
    figure(4)
    set(gcf,'PaperPositionMode','auto','Position', 8.5*v);
    for k=1:6
        
        subplot(2,3,1)  % firm's value
        plot(changes,J_all(:,k)); title('Value firm','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d); axis 'auto y';
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,3,2)  % worker's value
        plot(changes,workersValue(:,k)); title('Value worker','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d); axis 'auto y';
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,3,3); %value_of_unemp_at_0
        plot(changes,value_of_unemp_at_0(:,k)); title('Value unemployment (s=0)','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,3,4); %value_of_unemp_at_one_year
        plot(changes,value_of_unemp_at_1y(:,k)); title('Value unemployment (1 year)','FontSize',16)
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,3,5); %welfare
        plot(changes,EU(:,k)); title('Welfare','FontSize',16);
        set(gca,'FontSize',10)
        xlim(d);
        set(gca,'XTick',[-4 -3 -2 -1 0 1])
        hold all
        
        subplot(2,3,6)     
        leg2=plot(changes, 0);
        ylim([1 2])
        set(gca,'FontSize',20)
        axis(leg2,'off')
       % this is a fake subplot, just to show legend here
        
    end
        legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low','Location','NorthWest');
        legend('boxoff');    
    
    name=sprintf('%s%s','figure4_', string);
    saveas(gcf,name,'eps')

    
%% sBar and bUA steps

figure(6)
for k=1:6
    
    subplot(1,3,1)
%    plot(changes, sbar(:,k)); title('UI entitlement (sBar)','FontSize',20)
    plot(changes, sbar(:,k));  title('UI entitlement $\bar{s}$','interpreter','latex', 'FontSize',20) 
    set(gca,'FontSize',20)
    axis 'auto y';
    ylabel('months')
    xlim(d);
    set(gca,'XTick',[-4 -3 -2 -1 0 1])
    hold all
    
    subplot(1,3,2)
%    plot(changes, bUA(:,k)); title('bUA','FontSize',20)
    plot(changes, bUA(:,k)); title('UA payments $b_{UA}$','Interpreter','latex', 'FontSize',20)
    set(gca,'FontSize',20)
    ylabel('Euro')
%    if GraphType==1 || GraphType==2
    %ylim([90 200]);
 %   end
    xlim(d);
    set(gca,'XTick',[-4 -3 -2 -1 0 1])
    hold all
    
    subplot(1,3,3)     
    leg2=plot(changes, 0);
    ylim([1 2])
    set(gca,'FontSize',20)
    axis(leg2,'off')
   % this is a fake subplot, just to show legend here

end

%    h=legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low', 'Location','BestOutside');
h=legend('West-High','West-Medium', 'West-Low', 'East-High', 'East-Medium', 'East-Low','Location','NorthWest');
set(h,'Interpreter','none'); legend('boxoff')

name=sprintf('%s%s','sBar_bUA_steps_', string);
saveas(gcf,name,'eps')

hold off