function [mue_int, mue_bar, f] = densityProperties(mue_0,mue,InvData)

% paras
    infinity = InvData(13);
    
    steps = infinity; h = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% mue_bar is computed by integrating mue(s)*f(s) from zero to infinity 
% (compare paper), where f(s) is the duration density and infinity is 
% approximated by tauMax
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% first integrate the job arrival rate mue numerically by using the trapeze
% rule
    mue_int = NaN(1,steps); % preallocating memory
    mue_int(1) = 0.5 * h * (mue_0 + mue(1)); % initialize
    for j = 2:steps;
        % integrating by adding up trapezes to the left of j
        mue_int(j) = mue_int(j-1) + 0.5 * h * ( mue(j-1) + mue(j) );
    end

% calculate duration density with the numerical integrated mue, calculate
% the integrated density
    f = NaN(1,steps); % preallocating memory
    for j = 1:steps;
        f(j) = mue(j) * exp(-(mue_int(j))); % this stands for f(s) in eq. with marker f(s) in paper
    end
	f_int=0.5*h*(mue_0 + f(1));
    for j = 2:steps;
        f_int = f_int + 0.5 * h * (f(j-1)+f(j));
    end 

% Now that we have the density, we can calculate mue_bar
% Define auxiliary variable for integration in order to compute mue_bar
    auxVar = 0.5 * h * (mue_0 * mue_0 + (mue(1) * f(1)));
    for j = 2:steps;
        auxVar = auxVar + 0.5 * h * ( mue(j-1) * f(j-1) + mue(j) * f(j));
    end

% when mue is constant (after steps), the rest of the expectation can be 
% calculated using the known formula 
    %auxVar = auxVar + mue(steps,1) * exp(-mue(steps) * tauMax);
    auxVar = auxVar + mue(steps) * (1-f_int);

% assign the value of the auxiliary variable to mue_bar
    mue_bar = auxVar;

end