
% do comparativ static analysis
tic

%% prelims

% start with paras from PRSS
    clear
    load PRSS % to get initial values and parameter values
    fprintf('solving for %g groups, starting from %g and going to %g\n',K,K0,K1)
    
% flags
	AwFlag = 2; % block 2 is solved for wk theta and kappa
    ChoiceVarData= 1; %1- gives the real variable data, 2- data for testing the monotonicity
    numberRed = 6; % number of steps in comparative static analysis
    options = optimset('Display','iter');
    fastTest = 0; % 0: compute precisely 1: we do a quick programming test
    
%% start comparative static rounds        

for round = 1:numberRed
    
    fprintf('solving round %g of %g for comparative statics\n',round,numberRed)
    InvData(17) = round;

% initial conditions    
    wage0 = VarData(1,1:K); theta0 = VarData(7,1:K);
    y0 = [wage0,theta0];

if fastTest == 0
    
% start fsolve
    matlabpool open local 6
    options = optimset('Display','iter');
    [wTheta preci] = fsolve('block2',y0,options,InvData,VarData,K);
    matlabpool close

    wage = wTheta(1:K);	theta = wTheta(K+1:2*K);
    VarData(1,1:K) = wage; VarData(7,1:K) = theta; % save results in VarData such that it is used e.g. in block 1 below
    disp('solve_compStatic: now saved in VarData')
    
    for k = 1:K
        fprintf('solve_GE: wage of worker-type k = %g (at productivity: %g and ini cond %g)\n', wage(k),VarData(2,k),VarData(1,k))
    end
    fprintf('solve_GE: tightness (theta): %g at ini cond: %g\n', theta, theta0)
    fprintf('solve_GE: precision of fsolve: %g\n',preci)
    
% compute corresponding block 1 values    
    [employmentVector,UshortVector,UlongVector,mueIniVector,effortIniVector,mueBarVector,V0,Vbs,Vw,EU] = KtimesBlock1(InvData,VarData,K);

else
    display('>>>>>>>>>>>>>>>>> solve_compStatic: programme checking mode -- no true results <<<<<<<<<<<<<<<<<<<<')
    wage = wage0; theta = theta0;
    preci = -1.23456;
end
    
% complete block 2
    lambda = VarData(6,:); xiUI = VarData(8,:);
    xiUA = InvData(16);
    
    kappa = taxrate(wage,employmentVector,xiUI,UshortVector,xiUA,UlongVector);
    J = (A - wage/(1-kappa))./(rho + lambda); % vector with all the J_k
    
    AggregateUrate = sum(UshortVector+UlongVector)/sum(employmentVector+UshortVector+UlongVector);
    popSize = VarData(3,1:6);
    fprintf('solve_compStatic: we need zeros here: %g\n',employmentVector+UshortVector+UlongVector - popSize)
    uRates = (UshortVector+UlongVector)./(employmentVector+UshortVector+UlongVector);
    VOneYear = Vbs(:,13); % values of being unemployed after one year
        
% save results
    VarData(1,1:K) = wage; VarData(7,1:K) = theta;
    if round == 1 % just computed PRSS
        VarData(11,:) = xiUA * wage; 
    else % just computed Hartz or beyond Hartz
        % do nothing, VarData(11,:) already fixed by initial conditions for this round (see below)
    end

    filename = sprintf('%s%g','GE_compStatic_',round);
    save(filename,'round','preci','effortIniVector', 'mueBarVector', 'AggregateUrate', 'uRates', 'kappa', 'J','V0','VOneYear','Vw', 'EU', 'InvData','VarData');
    fprintf('\n~~~\nGE solved for round %g and results saved\n~~~\n\n',round) 

% graph
        cd '3 analyse' %
        productivityWageJ(A,VarData,J,kappa,K) % (Avector,VarData,J,kappa,K)
        cd .. %
        pause(.1)
        
% initial condition for next round
    if K == 6; % if we look at as many groups as in the paper 
        if round == 1 % now write initial condition for Hartz reform
            VarData(11,:) = VarData(11,:) .* [.95 .95 1.15 .7 .95 1.3]; % ordering of groups (see InputVariableData.m) WH WM WL EH EM EL
            VarData(9,:) = VarData(9,:) - [1 1 1 3 2 1]; % sBar for next round
        else % beyond Hartz
            VarData(11,:) = VarData(11,:) *.9; % bUA for next round
            VarData(9,:) = VarData(9,:) - [1 1 1 1 1 1]; % sBar for next round
        end
    elseif K == 1
        if round == 1 % now write initial condition for Hartz reform
            VarData(11,:) = VarData(11,:) .* .975; % bUA reduction due to Hartz IV
        else % beyond Hartz
            VarData(11,:) = VarData(11,:) *.9; % bUA for next round
        end 
        VarData(9,:) = VarData(9,:) - 1; % sBar for next round
    end
end

fprintf('done with comparative statics after %g seconds (%g minutes)\n',toc,toc/60)
if toc>3600
    fprintf('This amounts to %g hours\n',toc/3600)
end

%% now produce pictures and display results
    close all
    GraphsData % creates data for graphs amd saves them
    GraphsPlot % plots graphs (GraphsPlot can be run independently once data from GraphsData is saved)
    ShowValues % displays PRSS values (as shown by table in paper)
    Plot_PRSS % plots figure for PRSS
    
    disp('solve_compStatic: want to see changes in U rate due to reform?')
    disp('WARNING: workspace is deleted')
    disp('press any key when ready or CTRL-C to exit')
    pause()
    ShowUnemploymentRates