function [U,Ushort,Ulong] = unemployment(mue,mue_int,f,mueINIT,N,InvData,VarData)
% This function computes unemployment using the numerical values 
% of the probabilities Puu and Peu from smcPuu.m and smcprob.m

% paras

    sBar = VarData(9);
    infinity = InvData(13); 
    
% translate into traditional jargon
    steps = infinity;
    h = 1;
    steps_sbar = sBar;
    
% Now we create a matrix of mues that we need in the Semi-Markov-Part. 
% In the first column of the matrix, we find the mues over time for the 
% individual that has a s=0 in t. In the second column (k=2), we find 
% the mues for the individual that has a s=h in t. In the third column
% (k=3), we find the mues for the individual that has a s=2h in t... 
% and so on...
    for k=2:steps; % initialize for tau=t
        mueINIT(1,k)=mue(k-1,1);
    end;
    for k = 2:steps; % go on for tau=t+1...
        for j = 1:steps-1;
            mue(j,k) = mue(j+1,k-1);
        end;
     	    mue(steps,k) = mue(steps,k-1);
    end;    

%% Solving Semi-Markov-System
    
% Compute PuuStaumax and PeuTAUMAX using smcprob.m and smcPuu.m
% smcProb.m computes the probabilities P(e->u,tau|s=0) and Puu(u->u,tau|s=0)
% smcPuu.m computes the probabilities P(u->u,tau|s) for different s
    [P]=smcprob(InvData,VarData,mue,mueINIT,mue_int);
    PeuTAUMAX(1,1)=P(steps,1);
    [Puu]=smcPuu(InvData,VarData,mue,P,mueINIT);
    PuuStaumax=Puu(steps,:);

%% Computing Employment and Unemployment

    % PuuMUE2 is the probability that applies for the longterm unemployed 
    % for whom the probability of staying unemployed is constant (which is 
    % from tauMax (i.e. after #steps) onwards). 
        PuuMUE2 = PuuStaumax(steps);
        
    % Now we calculate the first part of the integral in the unemployment 
    % equation of the paper (until tauMax or #steps)    
    % Initialize
        PuuInt = 0;
    % Now integrate Puu(tau,s)*f(s) numerically
        for k = 2:steps;
            PuuInt = PuuInt+.5*h*( PuuStaumax(k-1)*mue(1,k-1)*exp(-mue_int(k-1)) + PuuStaumax(k)*mue(1,k)*exp(-mue_int(k)) );
        end;
      
    % The integrated density for the transition u->u
        PuuDensiInt = (PuuInt+PuuMUE2*exp(-mue_int(steps)));        

%% Compute (un)employment using the (un)employment equation from the paper
    
    % employment
    	L = (PuuDensiInt-1)*N/(PuuDensiInt-1-PeuTAUMAX(1));
        
    % unemployment (given by the difference between the labor market stock and employment)
        U = N - L;

    % integrate density until sbar numerically , i.e. compute share of 
    % short-term unemployed among all unemployed workers
    % f(.) is the duration density imported from muebar.m
        integer_steps_sbar = int16(steps_sbar);
        f_int = NaN(integer_steps_sbar); % oct 09 KW
        f_int(1) = 0.5 * h * (mueINIT(1,1) + f(1)); %initialize
        for j = 2:steps_sbar;
            f_int(j) = f_int(j-1) + .5 * h * (f(j-1)+f(j));
        end;

    % Compute short-term unemployment by multiplying the integrated density
    % with total unemployment; long-term unemployment is then total
    % unemployment minus short-term unemployment
        integer_steps_sbar = int16(steps_sbar); % KW oct 09
        %fprintf('greetings from unemployment.m: steps_sbar = %g, integer_steps_sbar = %g',steps_sbar,integer_steps_sbar);
        Ushort = f_int(integer_steps_sbar) * U;
        Ulong = U - Ushort;
end